@@ -94,7 +94,7 @@ class list_(Arbitrary):
     def gen_serial(self):
         def gen_for_depth(depth):
             for l in self.length.gen_serial():
-                if not (depth >= l or depth == 0):
+                if l > depth:
                     continue
 
                 if l == 0:
@@ -214,17 +214,18 @@ class dict_(MappedArbitrary):
 
     def __init__(self,
                  length=int_(0, 20),
-                 items=None,
                  keys=int_, values=int_):
-        if items is None:
-            items = tuple_((keys, values))
-        self.inner_arb = list_(length=length, elements=items)
+        self.inner_arb = tuple_((list_unique(length=length, elements=keys),
+                                 list_(length=length, elements=values)))
 
-    def pack(self, lst):
-        return dict(lst)
+    def pack(self, tup):
+        keys, values = tup
+        return dict(zip(keys, values))
 
     def unpack(self, dct):
-        return list(dct.items())
+        items = list(dct.items())
+        keys, values = zip(*items)
+        return (list(keys), list(values))
 
     @unique
     def gen_serial(self):
