@@ -1,3 +1,4 @@
+from collections import OrderedDict
 from functools import wraps
 import inspect
 from .checker import Checker
@@ -5,8 +6,8 @@ from .utils import optional_args
 
 
 @optional_args
-def qc(ntests=500):
-    """ qc(ntests=500)
+def qc(ntests=None, nshrinks=None, nassume=None):
+    """ qc(ntests=None, nshrinks=None, nassume=None)
     Decorator for a test function.
 
     For usage examples see :ref:`creating-tests`.
@@ -24,13 +25,13 @@ def qc(ntests=500):
         argnames = list(argspec.args or [])
         defaults = list(argspec.defaults or [])
         defaults = [None] * (len(argnames) - len(defaults)) + defaults
-        args = dict(zip(argnames, defaults))
+        args = OrderedDict(zip(argnames, defaults))
 
         if any(args[a] is None for a in args):
             raise TypeError('unbound variables: %s' %
                             ', '.join(a for a in args if args[a] is None))
 
-        checker = Checker(func, args, ntests, ignore_return=True)
+        checker = Checker(func, args, ntests, nshrinks, nassume, ignore_return=True)
 
         def wrapped(*args):
             if not (len(args) == 0 or len(args) == 1 and func_is_method):
